pub fn decode(bytes: &[u8], mode: DecodeMode) -> DecodedExpand description
Decodes the first complete key press at the front of bytes, read under the
given DecodeMode. See the module docs for the contract.
pub fn decode(bytes: &[u8], mode: DecodeMode) -> DecodedDecodes the first complete key press at the front of bytes, read under the
given DecodeMode. See the module docs for the contract.